@@ -9,7 +9,7 @@
  use Net::FTP;
  use vars '$AUTOLOAD';
 #-------------------------------------------------
- $Net::MirrorDir::VERSION = '0.07';
+ $Net::MirrorDir::VERSION = '0.08';
 #-------------------------------------------------
  sub new
  	{
@@ -29,9 +29,16 @@
  		_subset		=> $arg{subset}		|| [],
  		};
  	bless($self, $class || ref($class));
+	$self->_Init(%arg);
  	return($self);
  	}
 #-------------------------------------------------
+ sub _Init
+	{
+	warn("\n\ncall to abstract method _Init()\n");
+ 	return(0);
+	}
+#------------------------------------------------
  sub Connect
  	{
  	my ($self) = @_;
@@ -97,12 +104,12 @@
  				at Net::MirrorDir::ReadLocalDir() : $!\n");
  			my @files = readdir(PATH);
  			closedir(PATH);
- 			L_FILES: for my $file (@files)
+ 			L_FILE: for my $file (@files)
  				{
  				next if(($file eq ".") or ($file eq ".."));
  				for(@{$self->{_exclusions}})
  					{
- 					next("L_FILES") if(($file =~ m/$_/));
+ 					next("L_FILE") if(($file =~ m/$_/));
  					}
  				$self->{_readlocaldir}->($self, "$p/$file");
  				}
@@ -147,11 +154,11 @@
  			$self->{_connection}->cwd();
  			$self->{_remotedirs}{$p} = 1;
  			my @files = $self->{_connection}->ls($p);
-			R_FILES: for my $file (@files)
+			R_FILE: for my $file (@files)
  				{
  				for(@{$self->{_exclusions}})
  					{
- 					next("R_FILES") if(($file =~ m/$_/));
+ 					next("R_FILE") if(($file =~ m/$_/));
  					}
  				$self->{_readremotedir}->($self, "$p/$file");
  				}
@@ -308,8 +315,8 @@ Net::MirrorDir - Perl extension for compare local-directories and remote-directo
 #	exclusions	=> ["psw", "forbidden_code"]
 #	subset		=> ["name", "my_files"]
 # or you can use regular expressions
- 	exclusinos	=> [qr/SYSTEM/i, $regex]
- 	subset		=> {qr/(?i:HOME)(?i:PAGE)?/, $regex]
+# 	exclusinos	=> [qr/SYSTEM/i, $regex]
+# 	subset		=> {qr/(?i:HOME)(?i:PAGE)?/, $regex]
  	);
  $md->SetLocalDir("home/name/homepage");
  print("hostname : ", $md->get_ftpserver(), "\n");
@@ -467,6 +474,9 @@ The functions are generated by AUTOLOAD for arrayrefrences options.
 Like "subset" or "exclusions"
 The syntax is not case-sensitive and the character '_' is optional.
 
+=item (0) _Init(void)
+ Abstract method should be defined in every derived class.
+
 =head2 EXPORT
 
 None by default.
@@ -486,6 +496,10 @@ Net::FTP
 
 Maybe you'll find some. Let me know.
 
+=head1 REPORTING BUGS
+
+When reporting bugs/problems please include as much information as possible.
+
 =head1 AUTHOR
 
 Torsten Knorr, E<lt>create-soft@tiscali.deE<gt>
@@ -502,3 +516,7 @@ at your option, any later version of Perl 5 you may have available.
 =cut
 
 
+
+
+
+
